<script>

    window.resizeTo( 100,400 )

</script>
      
<div class="console">
<span align="center">
<p>
============Weblogic Node Master Web Access============
<p>
<p>

Author: Kevin Yi&ltyikaus @ gmail&gt
<p>
Homepage: http://yikaus.github.io/weblogic-node-master/
<p>
License  : BSD 
<p>
<p>
=======================================================

</span><p>
<textarea ng-model="output" class="output"></textarea> 

<form ng-submit="update(command)">
wlnm>>
<input ng-model="command" class="commandline" autofocus/>

</form>
<input  ng-model="prompt" class="prompt" value="Machine:None" disabled/>	

</div>
